NeuralFoil versions up to 0.1.10 pointed to `gen1_architecture` as the default model architecture.

NeuralFoil versions

Depending on the version of NeuralFoil (visible in [the top-level __init__.py](./__init__.py)), the default model architecture may be different. These are as follows:

* NeuralFoil 0.1.0 to 0.1.10: `gen1_architecture`
* NeuralFoil 0.2.0+: `gen2_architecture`